Learn R Programming

pomdp (version 1.2.7)

pomdp-package: pomdp: Infrastructure for Partially Observable Markov Decision Processes (POMDP)

Description

logo

Provides the infrastructure to define and analyze solutions to Partially Observable Markov Decision Process (POMDP) models. Interfaces to various exact and approximate solution algorithms are available, including value iteration, point-based value iteration, and SARSOP. Hahsler and Cassandra tools:::Rd_expr_doi("10.32614/RJ-2024-021").

Arguments

Key functions

  • Problem specification: POMDP, MDP

  • Solvers: solve_POMDP(), solve_MDP(), solve_SARSOP()

Author

Maintainer: Michael Hahsler [email protected] (ORCID) [copyright holder]

Authors:

Other contributors:

  • Hossein Kamalzadeh [contributor]

See Also